@@ -6,7 +6,7 @@ Created on 2018年11月23日
 '''
 from __future__ import print_function
 
-__version__ = '1.5.0'
+__version__ = '1.5.2'
 
 
 def md5(s):
@@ -22,6 +22,10 @@ def get_sign(salt, key):
     return md5(md5(salt) + md5(key))
 
 
+class XIOTException(Exception):
+    pass
+
+
 class App(object):
     '''用户应用'''
 
@@ -42,7 +46,7 @@ class App(object):
         headers = {"Content-Type": "application/json"}
         res = requests.post(url, data=json.dumps(data), headers=headers).json()
         if not res or res['code'] != 0:
-            raise Exception('%s:%s' % (res.get('code', -1), res.get('msg', '')))
+            raise XIOTException('%s:%s' % (res.get('code', -1), res.get('msg', '')))
         return res
 
 
